==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/model/MsCompanyQueryInfo.java <==
package com.xforceplus.seller.config.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 标准请求头
 */
@ApiModel(description = "标准请求头")

@JsonInclude(NON_NULL)
public class MsCompanyQueryInfo {
  @JsonProperty("organizationId")
  private List<Long> organizationId = new ArrayList<Long>();

  @JsonProperty("organizationName")
  private String organizationName = null;

  @JsonProperty("tenantId")
  private List<Long> tenantId = new ArrayList<Long>();

  @JsonProperty("tenantName")
  private String tenantName = null;

  @JsonProperty("companyId")
  private List<Long> companyId = new ArrayList<Long>();

  @JsonProperty("companyName")
  private String companyName = null;

  @JsonProperty("taxNo")
  private String taxNo = null;

  @JsonIgnore
  public MsCompanyQueryInfo organizationId(List<Long> organizationId) {
    this.organizationId = organizationId;
    return this;
  }

  public MsCompanyQueryInfo addOrganizationIdItem(Long organizationIdItem) {
    this.organizationId.add(organizationIdItem);
    return this;
  }

   /**
   * 组织id
   * @return organizationId
  **/
  @ApiModelProperty(value = "组织id")
  public List<Long> getOrganizationId() {
    return organizationId;
  }

  public void setOrganizationId(List<Long> organizationId) {
    this.organizationId = organizationId;
  }

  @JsonIgnore
  public MsCompanyQueryInfo organizationName(String organizationName) {
    this.organizationName = organizationName;
    return this;
  }

   /**
   * 组织名称
   * @return organizationName
  **/
  @ApiModelProperty(value = "组织名称")
  public String getOrganizationName() {
    return organizationName;
  }

  public void setOrganizationName(String organizationName) {
    this.organizationName = organizationName;
  }

  @JsonIgnore
  public MsCompanyQueryInfo tenantId(List<Long> tenantId) {
    this.tenantId = tenantId;
    return this;
  }

  public MsCompanyQueryInfo addTenantIdItem(Long tenantIdItem) {
    this.tenantId.add(tenantIdItem);
    return this;
  }

   /**
   * 租户id
   * @return tenantId
  **/
  @ApiModelProperty(value = "租户id")
  public List<Long> getTenantId() {
    return tenantId;
  }

  public void setTenantId(List<Long> tenantId) {
    this.tenantId = tenantId;
  }

  @JsonIgnore
  public MsCompanyQueryInfo tenantName(String tenantName) {
    this.tenantName = tenantName;
    return this;
  }

   /**
   * 租户名称
   * @return tenantName
  **/
  @ApiModelProperty(value = "租户名称")
  public String getTenantName() {
    return tenantName;
  }

  public void setTenantName(String tenantName) {
    this.tenantName = tenantName;
  }

  @JsonIgnore
  public MsCompanyQueryInfo companyId(List<Long> companyId) {
    this.companyId = companyId;
    return this;
  }

  public MsCompanyQueryInfo addCompanyIdItem(Long companyIdItem) {
    this.companyId.add(companyIdItem);
    return this;
  }

   /**
   * 公司id
   * @return companyId
  **/
  @ApiModelProperty(value = "公司id")
  public List<Long> getCompanyId() {
    return companyId;
  }

  public void setCompanyId(List<Long> companyId) {
    this.companyId = companyId;
  }

  @JsonIgnore
  public MsCompanyQueryInfo companyName(String companyName) {
    this.companyName = companyName;
    return this;
  }

   /**
   * 公司名称
   * @return companyName
  **/
  @ApiModelProperty(value = "公司名称")
  public String getCompanyName() {
    return companyName;
  }

  public void setCompanyName(String companyName) {
    this.companyName = companyName;
  }

  @JsonIgnore
  public MsCompanyQueryInfo taxNo(String taxNo) {
    this.taxNo = taxNo;
    return this;
  }

   /**
   * 纳税人识别号
   * @return taxNo
  **/
  @ApiModelProperty(value = "纳税人识别号")
  public String getTaxNo() {
    return taxNo;
  }

  public void setTaxNo(String taxNo) {
    this.taxNo = taxNo;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsCompanyQueryInfo companyQueryInfo = (MsCompanyQueryInfo) o;
    return Objects.equals(this.organizationId, companyQueryInfo.organizationId) &&
        Objects.equals(this.organizationName, companyQueryInfo.organizationName) &&
        Objects.equals(this.tenantId, companyQueryInfo.tenantId) &&
        Objects.equals(this.tenantName, companyQueryInfo.tenantName) &&
        Objects.equals(this.companyId, companyQueryInfo.companyId) &&
        Objects.equals(this.companyName, companyQueryInfo.companyName) &&
        Objects.equals(this.taxNo, companyQueryInfo.taxNo);
  }

  @Override
  public int hashCode() {
    return Objects.hash(organizationId, organizationName, tenantId, tenantName, companyId, companyName, taxNo);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsCompanyQueryInfo {\n");
    
    sb.append("    organizationId: ").append(toIndentedString(organizationId)).append("\n");
    sb.append("    organizationName: ").append(toIndentedString(organizationName)).append("\n");
    sb.append("    tenantId: ").append(toIndentedString(tenantId)).append("\n");
    sb.append("    tenantName: ").append(toIndentedString(tenantName)).append("\n");
    sb.append("    companyId: ").append(toIndentedString(companyId)).append("\n");
    sb.append("    companyName: ").append(toIndentedString(companyName)).append("\n");
    sb.append("    taxNo: ").append(toIndentedString(taxNo)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> seller-config-client-api-4.1.30-20250928.033323-2-sources.jar: com/xforceplus/seller/config/client/model/MsCompanyQueryInfo.java <==
package com.xforceplus.seller.config.client.model;

import java.io.Serializable;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 标准请求头
 */
@ApiModel(description = "标准请求头")

@JsonInclude(NON_NULL)
public class MsCompanyQueryInfo implements Serializable {
  @JsonProperty("organizationId")
  private List<Long> organizationId = new ArrayList<Long>();

  @JsonProperty("organizationName")
  private String organizationName = null;

  @JsonProperty("tenantId")
  private List<Long> tenantId = new ArrayList<Long>();

  @JsonProperty("tenantName")
  private String tenantName = null;

  @JsonProperty("companyId")
  private List<Long> companyId = new ArrayList<Long>();

  @JsonProperty("companyName")
  private String companyName = null;

  @JsonProperty("taxNo")
  private String taxNo = null;

  @JsonIgnore
  public MsCompanyQueryInfo organizationId(List<Long> organizationId) {
    this.organizationId = organizationId;
    return this;
  }

  public MsCompanyQueryInfo addOrganizationIdItem(Long organizationIdItem) {
    this.organizationId.add(organizationIdItem);
    return this;
  }

   /**
   * 组织id
   * @return organizationId
  **/
  @ApiModelProperty(value = "组织id")
  public List<Long> getOrganizationId() {
    return organizationId;
  }

  public void setOrganizationId(List<Long> organizationId) {
    this.organizationId = organizationId;
  }

  @JsonIgnore
  public MsCompanyQueryInfo organizationName(String organizationName) {
    this.organizationName = organizationName;
    return this;
  }

   /**
   * 组织名称
   * @return organizationName
  **/
  @ApiModelProperty(value = "组织名称")
  public String getOrganizationName() {
    return organizationName;
  }

  public void setOrganizationName(String organizationName) {
    this.organizationName = organizationName;
  }

  @JsonIgnore
  public MsCompanyQueryInfo tenantId(List<Long> tenantId) {
    this.tenantId = tenantId;
    return this;
  }

  public MsCompanyQueryInfo addTenantIdItem(Long tenantIdItem) {
    this.tenantId.add(tenantIdItem);
    return this;
  }

   /**
   * 租户id
   * @return tenantId
  **/
  @ApiModelProperty(value = "租户id")
  public List<Long> getTenantId() {
    return tenantId;
  }

  public void setTenantId(List<Long> tenantId) {
    this.tenantId = tenantId;
  }

  @JsonIgnore
  public MsCompanyQueryInfo tenantName(String tenantName) {
    this.tenantName = tenantName;
    return this;
  }

   /**
   * 租户名称
   * @return tenantName
  **/
  @ApiModelProperty(value = "租户名称")
  public String getTenantName() {
    return tenantName;
  }

  public void setTenantName(String tenantName) {
    this.tenantName = tenantName;
  }

  @JsonIgnore
  public MsCompanyQueryInfo companyId(List<Long> companyId) {
    this.companyId = companyId;
    return this;
  }

  public MsCompanyQueryInfo addCompanyIdItem(Long companyIdItem) {
    this.companyId.add(companyIdItem);
    return this;
  }

   /**
   * 公司id
   * @return companyId
  **/
  @ApiModelProperty(value = "公司id")
  public List<Long> getCompanyId() {
    return companyId;
  }

  public void setCompanyId(List<Long> companyId) {
    this.companyId = companyId;
  }

  @JsonIgnore
  public MsCompanyQueryInfo companyName(String companyName) {
    this.companyName = companyName;
    return this;
  }

   /**
   * 公司名称
   * @return companyName
  **/
  @ApiModelProperty(value = "公司名称")
  public String getCompanyName() {
    return companyName;
  }

  public void setCompanyName(String companyName) {
    this.companyName = companyName;
  }

  @JsonIgnore
  public MsCompanyQueryInfo taxNo(String taxNo) {
    this.taxNo = taxNo;
    return this;
  }

   /**
   * 纳税人识别号
   * @return taxNo
  **/
  @ApiModelProperty(value = "纳税人识别号")
  public String getTaxNo() {
    return taxNo;
  }

  public void setTaxNo(String taxNo) {
    this.taxNo = taxNo;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsCompanyQueryInfo companyQueryInfo = (MsCompanyQueryInfo) o;
    return Objects.equals(this.organizationId, companyQueryInfo.organizationId) &&
        Objects.equals(this.organizationName, companyQueryInfo.organizationName) &&
        Objects.equals(this.tenantId, companyQueryInfo.tenantId) &&
        Objects.equals(this.tenantName, companyQueryInfo.tenantName) &&
        Objects.equals(this.companyId, companyQueryInfo.companyId) &&
        Objects.equals(this.companyName, companyQueryInfo.companyName) &&
        Objects.equals(this.taxNo, companyQueryInfo.taxNo);
  }

  @Override
  public int hashCode() {
    return Objects.hash(organizationId, organizationName, tenantId, tenantName, companyId, companyName, taxNo);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsCompanyQueryInfo {\n");
    
    sb.append("    organizationId: ").append(toIndentedString(organizationId)).append("\n");
    sb.append("    organizationName: ").append(toIndentedString(organizationName)).append("\n");
    sb.append("    tenantId: ").append(toIndentedString(tenantId)).append("\n");
    sb.append("    tenantName: ").append(toIndentedString(tenantName)).append("\n");
    sb.append("    companyId: ").append(toIndentedString(companyId)).append("\n");
    sb.append("    companyName: ").append(toIndentedString(companyName)).append("\n");
    sb.append("    taxNo: ").append(toIndentedString(taxNo)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
